==> tekton-model-triggers-v1alpha1-6.3.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/NamespaceSelectorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NamespaceSelectorFluentImpl<A extends NamespaceSelectorFluent<A>> extends BaseFluent<A> implements NamespaceSelectorFluent<A>{
  public NamespaceSelectorFluentImpl() {
  }
  public NamespaceSelectorFluentImpl(NamespaceSelector instance) {
    this.withMatchNames(instance.getMatchNames()); 
  }
  private List<String> matchNames = new ArrayList<String>();
  public A addToMatchNames(Integer index,String item) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    this.matchNames.add(index, item);
    return (A)this;
  }
  public A setToMatchNames(Integer index,String item) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    this.matchNames.set(index, item); return (A)this;
  }
  public A addToMatchNames(java.lang.String... items) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    for (String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A addAllToMatchNames(Collection<String> items) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    for (String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A removeFromMatchNames(java.lang.String... items) {
    for (String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public A removeAllFromMatchNames(Collection<String> items) {
    for (String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public List<String> getMatchNames() {
    return this.matchNames;
  }
  public String getMatchName(Integer index) {
    return this.matchNames.get(index);
  }
  public String getFirstMatchName() {
    return this.matchNames.get(0);
  }
  public String getLastMatchName() {
    return this.matchNames.get(matchNames.size() - 1);
  }
  public String getMatchingMatchName(Predicate<String> predicate) {
    for (String item: matchNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingMatchName(Predicate<String> predicate) {
    for (String item: matchNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchNames(List<String> matchNames) {
    if (matchNames != null) {this.matchNames = new ArrayList(); for (String item : matchNames){this.addToMatchNames(item);}} else { this.matchNames = null;} return (A) this;
  }
  public A withMatchNames(java.lang.String... matchNames) {
    if (this.matchNames != null) {this.matchNames.clear();}
    if (matchNames != null) {for (String item :matchNames){ this.addToMatchNames(item);}} return (A) this;
  }
  public Boolean hasMatchNames() {
    return matchNames != null && !matchNames.isEmpty();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamespaceSelectorFluentImpl that = (NamespaceSelectorFluentImpl) o;
    if (matchNames != null ? !matchNames.equals(that.matchNames) :that.matchNames != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchNames,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchNames != null && !matchNames.isEmpty()) { sb.append("matchNames:"); sb.append(matchNames); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/NamespaceSelectorFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.function.Predicate;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NamespaceSelectorFluentImpl<A extends NamespaceSelectorFluent<A>> extends BaseFluent<A> implements NamespaceSelectorFluent<A>{
  public NamespaceSelectorFluentImpl() {
  }
  public NamespaceSelectorFluentImpl(NamespaceSelector instance) {
    if (instance != null) {
      this.withMatchNames(instance.getMatchNames());
    }
  }
  private List<String> matchNames = new ArrayList<String>();
  public A addToMatchNames(int index,String item) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    this.matchNames.add(index, item);
    return (A)this;
  }
  public A setToMatchNames(int index,String item) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    this.matchNames.set(index, item); return (A)this;
  }
  public A addToMatchNames(java.lang.String... items) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    for (String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A addAllToMatchNames(Collection<String> items) {
    if (this.matchNames == null) {this.matchNames = new ArrayList<String>();}
    for (String item : items) {this.matchNames.add(item);} return (A)this;
  }
  public A removeFromMatchNames(java.lang.String... items) {
    for (String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public A removeAllFromMatchNames(Collection<String> items) {
    for (String item : items) {if (this.matchNames!= null){ this.matchNames.remove(item);}} return (A)this;
  }
  public List<String> getMatchNames() {
    return this.matchNames;
  }
  public String getMatchName(int index) {
    return this.matchNames.get(index);
  }
  public String getFirstMatchName() {
    return this.matchNames.get(0);
  }
  public String getLastMatchName() {
    return this.matchNames.get(matchNames.size() - 1);
  }
  public String getMatchingMatchName(Predicate<String> predicate) {
    for (String item: matchNames) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingMatchName(Predicate<String> predicate) {
    for (String item: matchNames) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withMatchNames(List<String> matchNames) {
    if (matchNames != null) {this.matchNames = new ArrayList(); for (String item : matchNames){this.addToMatchNames(item);}} else { this.matchNames = null;} return (A) this;
  }
  public A withMatchNames(java.lang.String... matchNames) {
    if (this.matchNames != null) {this.matchNames.clear(); _visitables.remove("matchNames"); }
    if (matchNames != null) {for (String item :matchNames){ this.addToMatchNames(item);}} return (A) this;
  }
  public Boolean hasMatchNames() {
    return matchNames != null && !matchNames.isEmpty();
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NamespaceSelectorFluentImpl that = (NamespaceSelectorFluentImpl) o;
    if (!java.util.Objects.equals(matchNames, that.matchNames)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchNames,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchNames != null && !matchNames.isEmpty()) { sb.append("matchNames:"); sb.append(matchNames); }
    sb.append("}");
    return sb.toString();
  }
  
}
